@@ -6,7 +6,8 @@ import typing as t
 import peewee as pw
 import marshmallow as ma
 from muffin_peewee import JSONField
-from muffin_rest.peewee import PWRESTBase, PWRESTOptions, PWFilter, Filter
+from muffin_rest.peewee import PWRESTBase, PWRESTOptions
+from muffin_rest.peewee.filters import PWFilter
 
 from ..handler import AdminHandler, AdminOptions
 from ..typing import RA_INFO
@@ -20,15 +21,20 @@ class PWAdminOptions(AdminOptions, PWRESTOptions):
         """Auto insert filter by id."""
         super(PWAdminOptions, self).setup(cls)
 
-        for f in self.filters:
-            if isinstance(f, Filter):
-                f = f.name
+        for flt in self.filters:
+            name = flt
 
-            if f == 'id':
+            if isinstance(flt, PWFilter):
+                name = flt.name
+
+            elif isinstance(flt, tuple):
+                name = flt[0]
+
+            if name == 'id':
                 break
 
         else:
-            self.filters = [PWFilter('id', pw_field=self.model_pk), *self.filters]
+            self.filters = [PWFilter('id', field=self.model_pk), *self.filters]
 
 
 class PWAdminHandler(AdminHandler, PWRESTBase):
@@ -44,6 +50,16 @@ class PWAdminHandler(AdminHandler, PWRESTBase):
 
         abc = True
 
+    @classmethod
+    def to_ra_field(cls, field: ma.fields.Field, source: str) -> RA_INFO:
+        """Setup RA fields."""
+        model_field = getattr(cls.meta.model, field.attribute or source, None)
+        if model_field and \
+                (isinstance(model_field, JSONField) or model_field.field_type.lower() == 'json'):
+            return 'JsonField', {}
+
+        return super(PWAdminHandler, cls).to_ra_field(field, source)
+
     @classmethod
     def to_ra_input(cls, field: ma.fields.Field, source: str) -> RA_INFO:
         """Setup RA inputs."""
@@ -60,18 +76,22 @@ class PWAdminHandler(AdminHandler, PWRESTBase):
             if isinstance(model_field, JSONField) or model_field.field_type.lower() == 'json':
                 return 'JsonInput', props
 
+            if isinstance(model_field, pw.ForeignKeyField):
+                ref = model_field.rel_model._meta.table_name
+                if ref in cls.meta.references:
+                    props = dict(
+                        props, reference=ref, allowEmpty=model_field.null,
+                        refProp=cls.meta.references[ref],
+                        refSource=model_field.rel_field.name,
+                    )
+                    return 'FKInput', dict(
+                        props, reference=ref, allowEmpty=model_field.null,
+                        refProp=cls.meta.references[ref],
+                        refSource=model_field.rel_field.name,
+                    )
+
         return ra_type, props
 
-    @classmethod
-    def to_ra_field(cls, field: ma.fields.Field, source: str) -> RA_INFO:
-        """Setup RA fields."""
-        model_field = getattr(cls.meta.model, field.attribute or source, None)
-        if model_field and \
-                (isinstance(model_field, JSONField) or model_field.field_type.lower() == 'json'):
-            return 'JsonField', {}
-
-        return super(PWAdminHandler, cls).to_ra_field(field, source)
-
 
 class PWSearchFilter(PWFilter):
 
